@@ -6,13 +6,13 @@ use Carp;
 use Time::HiRes;
 use Config;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 our $DEBUG = $ENV{FORKS_QUEUE_DEBUG} || 0;
 
 our $NOTIFY_OK = $ENV{FORKS_QUEUE_NOTIFY} // do {
     $Config::Config{sig_name} =~ /\bIO\b/;
-    1;
 };
+
 our $SLEEP_INTERVAL = $NOTIFY_OK ? 2 : 1;
 our $SLEEP_INTERVALX = 2;
 
@@ -21,11 +21,11 @@ our %OPTS = (limit => -1, on_limit => 'fail', style => 'fifo',
              impl => $ENV{FORKS_QUEUE_IMPL} || 'File' );
 
 sub new {
-    my $pkg = shift;
+    my $class = shift;
     my %opts = (%OPTS, @_);
 
     if ($opts{impl}) {
-        $pkg = delete $opts{impl};
+        my $pkg = delete $opts{impl};
         if ($pkg =~ /[^\w:]/) {
             croak "Forks::Queue cannot be instantiated. Invalid 'impl' $pkg";
         }
@@ -193,7 +193,7 @@ Forks::Queue - queue that can be shared across processes
 
 =head1 VERSION
 
-0.06
+0.07
 
 =head1 SYNOPSIS
 
@@ -769,7 +769,5 @@ See http://dev.perl.org/licenses/ for more information.
 #
 #     priorities
 #     Directory implementation (see Queue::Dir)
-# _X_ Better thread support
 #     network implementation with simple client-server
-#     even better thread support, 2nd signal from main to threads    
-#     import function to set global impl, limit, on_limit settings
+#     even better thread support, 2nd signal from main to threads?
