@@ -9,7 +9,7 @@ use Time::HiRes 'time';
 use base 'Forks::Queue';
 use 5.010;    #  using  // //=  operators
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 our ($DEBUG,$XDEBUG);
 *DEBUG = \$Forks::Queue::DEBUG;
 
@@ -785,31 +785,31 @@ sub _impute_file {
 }
 
 sub _DUMP {
-    my ($self,$dfh) = @_;
+    my ($self,$fh_dump) = @_;
     my $dbh = $self->_dbh;
-    $dfh ||= *STDERR;
+    $fh_dump ||= *STDERR;
 
     my $sth = $dbh->prepare("SELECT * FROM pids");
     my $z = $sth->execute;
-    print $dfh "\n\n=== pids ===\n------------\n";
+    print {$fh_dump} "\n\n=== pids ===\n------------\n";
     foreach my $r (@{$sth->fetchall_arrayref}) {
-        print $dfh join("\t",@$r),"\n";
+        print {$fh_dump} join("\t",@$r),"\n";
     }
 
     $sth = $dbh->prepare("SELECT * FROM status");
     $z = $sth->execute;
-    print $dfh "\n\n=== status ===\n--------------\n";
+    print {$fh_dump} "\n\n=== status ===\n--------------\n";
     foreach my $r (@{$sth->fetchall_arrayref}) {
-        print $dfh join("\t",@$r),"\n";
+        print {$fh_dump} join("\t",@$r),"\n";
     }
 
     $sth = $dbh->prepare("SELECT * FROM the_queue");
     $z = $sth->execute;
-    print $dfh "\n\n=== queue ===\n-------------\n";
+    print {$fh_dump} "\n\n=== queue ===\n-------------\n";
     foreach my $r (@{$sth->fetchall_arrayref}) {
-        print $dfh join("\t",@$r),"\n";
+        print {$fh_dump} join("\t",@$r),"\n";
     }
-    print $dfh "\n\n";
+    print {$fh_dump} "\n\n";
 }
 
 1;
@@ -820,7 +820,7 @@ Forks::Queue::SQLite - SQLite-based implementation of Forks::Queue
 
 =head1 VERSION
 
-0.06
+0.07
 
 =head1 SYNOPSIS
 
